# hydroutils


[![image](https://img.shields.io/pypi/v/hydroutils.svg)](https://pypi.python.org/pypi/hydroutils)
[![image](https://img.shields.io/conda/vn/conda-forge/hydroutils.svg)](https://anaconda.org/conda-forge/hydroutils)

[![image](https://pyup.io/repos/github/OuyangWenyu/hydroutils/shield.svg)](https://pyup.io/repos/github/OuyangWenyu/hydroutils)


**A collection of commonly used util functions in hydrological modeling**


-   Free software: MIT license
-   Documentation: https://OuyangWenyu.github.io/hydroutils
    

## Features

This is a very basic package that contains some commonly used functions in hydrological modeling. The functions are organized into several modules, including:

- hydro_arithmetic: Arithmetic operations for hydrological variables
- hydro_file: File operations for hydrological variables
- hydro_plot: Plotting functions for hydrological variables
- hydro_stat: Statistical functions for hydrological variables
- hydro_time: Time series operations for hydrological variables

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
